#include <iostream>
#include <vector>
#include <cstdlib>
#include <queue>

#define INF 2000000000
#define UP 1000

using namespace std;

typedef long long ll;
typedef vector<ll> vi;
typedef vector<vi> vvi;
typedef pair<ll, ll> ii;
typedef vector<ii> vii;

void floyd_warshall(vvi &adj_matrix, ll n) {
    for (ll k = 0; k < n; ++k)
        for (ll i = 0; i < n; ++i)
            for (ll j = 0; j < n; ++j)
                adj_matrix[i][j] = min(adj_matrix[i][j], adj_matrix[i][k] + adj_matrix[k][j]);
}

void get_distances(vvi &adj_matrix, ll n) {
    vvi adj_list(n);
    for (ll i = 0; i < n; ++i) {
        for (ll j = 0; j < n; ++j) {
            if (i == j) continue;

            if (adj_matrix[i][j] < INF) {
                adj_list[i].push_back(j);
            }
        }
    }

    for (ll start = 0; start < n; ++start) {
        queue<ll> q;
        q.push(start);
        vi dist(n, INF);
        dist[start] = 0;
        while (!q.empty()) {
            ll cur = q.front(); q.pop();
            for (ll i = 0; i < adj_list[cur].size(); ++i) {
                ll v = adj_list[cur][i];
                if (dist[v] == INF) {
                    dist[v] = dist[cur] + adj_matrix[cur][v];
                    q.push(v);
                }
            }
        }
        adj_matrix[start] = dist;
    }
}

ll get_and_remove(vi &vertices) {
    ll idx = rand() % vertices.size();
    ll ans = vertices[idx];
    vertices.erase(vertices.begin()+idx);
    return ans;
}

// cases desired:
// line graph
// star graph
// tree with arbitrary geometric degree growth (~ log n diameter)
// tree with small growth (larger diameter)
// of sizes small, medium, large, large again
vvi generate_case(ll n) {
    vvi adj_matrix(n, vi(n, INF));
    vi vertices;

    for (ll i = 0; i < n; ++i) {
        vertices.push_back(i);
    }

    /*
    ll prev = get_and_remove(vertices);
    for (ll i = 0; i < n-1; ++i) {
        ll next = get_and_remove(vertices);

        adj_matrix[prev][next] = rand()%UP + 1;
        prev = next;
    }*/

    /*
    ll center = rand()%n;
    for (ll i = 0; i < n; ++i) {
        if (i == center) continue;

        adj_matrix[i][center] = rand()%UP + 1;
    }*/

    queue<ll> q;
    q.push(get_and_remove(vertices));
    while (!q.empty()) {
        ll cur = q.front(); q.pop();

        ll n_neighbors = 1;
        if (rand()%200 == 0) {
            n_neighbors = rand() % 3 + 1;
        }
        n_neighbors = min(n_neighbors, (ll)vertices.size());
        //ll n_neighbors = min((ll)rand()%(n/2), (ll)vertices.size());
        for (ll i = 0; i < n_neighbors; ++i) {
            ll neighbor = get_and_remove(vertices);

            adj_matrix[cur][neighbor] = rand()%UP + 1;
            q.push(neighbor);
        }
    }

    return adj_matrix;
}

int main(int argc, char **argv) {
    srand(9);

    ll n = 253;
    vvi adj_matrix = generate_case(n);
    
    for (ll i = 0; i < n; ++i) {
        adj_matrix[i][i] = 0;
        for (ll j = 0; j < n; ++j)
            adj_matrix[i][j] = min(adj_matrix[i][j], adj_matrix[j][i]);
    }
   
   
    if (argc > 1) {
        for (ll i = 0; i < n; ++i)
            for (ll j = i+1; j < n; ++j)
                if (adj_matrix[i][j] < INF)
                    cout << i+1 << " " << j+1 << endl;
    }
    else {
        get_distances(adj_matrix, n);
        
        for (ll i = 0; i < n; ++i)
            for (ll j = 0; j < n; ++j)
                if (adj_matrix[i][j] > 10000000)
                    cerr << adj_matrix[i][j];
        
        cout << n << endl;
        for (ll i = 0; i < n; ++i) {
            cout << adj_matrix[i][0];
            for (ll j = 1; j < n; ++j) {
                cout << " " << adj_matrix[i][j];
            }
            cout << endl;
        }
    }
}
